@@ -1,10 +1,8 @@
-from wordle.dictionary import words
+from wordle.dictionary import jumbled_words
 from datetime import datetime as dt
-import random
 import math
 
 UNIX_reference = 1645678800
-jumbled_words = random.sample(words, len(words))
 
 def random_answer(daily: bool):
     """Picks a random answer every day."""
