@@ -89,4 +89,6 @@ class Wordle:
                     print(f"Congratulations, you passed the wordle in {i + 1} tries.")
                 else:
                     raise Exception("Fatal iteration error for largest for loop.")
-                quit()
\ No newline at end of file
+                quit()
+        print("You failed.")
+        quit()
\ No newline at end of file
